#!/usr/bin/gnuplot

deg = pi/180.
yr = 365.25*86400.
Myr = 1.e6*yr
g = 1.e-3
cm = 1.e-2
km = 1.e3
M_S = 1.989e30  # kg
au = 1.496e11  # m
G = 6.67e-11

R = 100.*km/2.
rho = 3.0 * g/cm**3
I = 1.*deg
I = 5.*deg
C = 0.48

Sigma0 = 750. * g/cm**2
slope = -0.5
r = 2.36*au
h = 0.05

########################################################################

# midplane v_rel is indeed v_k sin I,
# BUT what is correct out-of-plane v_rel?

v_k = sqrt(G*M_S/r)
v_rel(I) = v_k*sin(I)
Sigma = Sigma0 * (r/au)**slope
H = h*r
rho_gas = Sigma/H

m(R) = 4./3.*pi*R**3 * rho
S(R) = pi*R**2
p(R) = m(R)*v_k
F(R,I) = 1./2.*C*S(R)*rho_gas*v_rel(I)**2
tau(R,I) = p(R)/F(R,I)

rho_gas_(I) = rho_gas * exp(-(r*tan(I)/H)**2)
F_(R,I) = 1./2.*C*S(R)*rho_gas_(I)*(v_rel(I))**2
tau_(R,I) = p(R)/F_(R,I)

# dp/dt = F
# p/tau = F
# tau = p/F

print "v_k = ", v_k/km, " km/s"
print "I = ", I, " rad = ", I/deg, " deg"
print "v_rel = ", v_rel(I)/km, " km/s"
print "Sigma = ", Sigma/(g*cm**(-2)), " g cm^-2"
print "H = ", H/cm, " cm = ", H/au, " au"
print "rho_gas = ", rho_gas/(g*cm**(-3)), " g cm^-3"

print "R = ", R/km, " km (Vesta)"
print "p = ", p(R), " kg m s^-1"
print "F = ", F(R,I), " N"
print "F' = ", F_(R,I), " N"
print "tau = ", tau(R,I)/Myr, " Myr (midplane)"
print "tau' = ", tau_(R,I)/Myr, " Myr (out-of-plane)"

########################################################################

set term x11

set xl "D [km]"
set yl "I [deg]"
set zl "tau, tau' [Myr]"

set xr [100:500]
set yr [1:20]
set zr [:1000]
set logscale z
set ticslevel 0

sp \
  tau(x*km/2.,y*deg)/Myr,\
  tau_(x*km/2.,y*deg)/Myr,\
  "<echo 1 1 1" u (2*R/km):(I/deg):(tau(R,I)/Myr) w p ps 2

pa -1


